# -*- coding: utf-8 -*-
from django.db import models


class Estado(models.Model):
    estado = models.CharField(max_length=50)
    iso_3166_2 = models.CharField(max_length=5)

    def __unicode__(self):
        return self.estado

    class Meta:
        verbose_name = u'Estado'
        verbose_name_plural = u'Estados'


class Ciudad(models.Model):
    estado = models.ForeignKey('Estado')
    ciudad = models.CharField(max_length=100)
    capital = models.IntegerField(default=0)

    def __unicode__(self):
        return self.ciudad

    class Meta:
        verbose_name = u'Ciudad'
        verbose_name_plural = u'Ciudades'


class Municipio(models.Model):
    estado = models.ForeignKey('Estado')
    municipio = models.CharField(max_length=100)

    def __unicode__(self):
        return self.municipio

    class Meta:
        verbose_name = u'Municipio'
        verbose_name_plural = u'Municipios'


class Parroquia(models.Model):
    municipio = models.ForeignKey('Municipio')
    parroquia = models.CharField(max_length=100)

    def __unicode__(self):
        return self.parroquia

    class Meta:
        verbose_name = u'Parroquía'
        verbose_name_plural = u'Parroquías'


# -*- coding: utf-8 -*-
from south.utils import datetime_utils as datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models


class Migration(SchemaMigration):

    def forwards(self, orm):
        # Adding model 'Estado'
        db.create_table(u'venezuela_estado', (
            (u'id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('estado', self.gf('django.db.models.fields.CharField')(max_length=50)),
        ))
        db.send_create_signal(u'venezuela', ['Estado'])


    def backwards(self, orm):
        # Deleting model 'Estado'
        db.delete_table(u'venezuela_estado')


    models = {
        u'venezuela.estado': {
            'Meta': {'object_name': 'Estado'},
            'estado': ('django.db.models.fields.CharField', [], {'max_length': '50'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'})
        }
    }

    complete_apps = ['venezuela']


# -*- coding: utf-8 -*-
from south.utils import datetime_utils as datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models


class Migration(SchemaMigration):

    def forwards(self, orm):
        # Adding field 'Estado.iso_3166_2'
        db.add_column(u'venezuela_estado', 'iso_3166_2',
                      self.gf('django.db.models.fields.CharField')(default='', max_length=5),
                      keep_default=False)


    def backwards(self, orm):
        # Deleting field 'Estado.iso_3166_2'
        db.delete_column(u'venezuela_estado', 'iso_3166_2')


    models = {
        u'venezuela.ciudad': {
            'Meta': {'object_name': 'Ciudad'},
            'capital': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'ciudad': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'estado': ('django.db.models.fields.related.ForeignKey', [], {'to': u"orm['venezuela.Estado']"}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'})
        },
        u'venezuela.estado': {
            'Meta': {'object_name': 'Estado'},
            'estado': ('django.db.models.fields.CharField', [], {'max_length': '50'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'iso_3166_2': ('django.db.models.fields.CharField', [], {'max_length': '5'})
        },
        u'venezuela.municipio': {
            'Meta': {'object_name': 'Municipio'},
            'estado': ('django.db.models.fields.related.ForeignKey', [], {'to': u"orm['venezuela.Estado']"}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'municipio': ('django.db.models.fields.CharField', [], {'max_length': '100'})
        },
        u'venezuela.parroquia': {
            'Meta': {'object_name': 'Parroquia'},
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'municipio': ('django.db.models.fields.related.ForeignKey', [], {'to': u"orm['venezuela.Municipio']"}),
            'parroquia': ('django.db.models.fields.CharField', [], {'max_length': '100'})
        }
    }

    complete_apps = ['venezuela']


# -*- coding: utf-8 -*-
import os
from setuptools import setup

README = open(os.path.join(os.path.dirname(__file__), 'README.rst')).read()

# allow setup.py to be run from any path
os.chdir(os.path.normpath(os.path.join(os.path.abspath(__file__), os.pardir)))

setup(
    name='django-venezuela',
    version='0.4.1',
    packages=['venezuela'],
    include_package_data=True,
    license='GPL v2 License',
    description=u'Aplicación en Django que contiene los modelos de estados, ciudades, municipios y '
                u'parroquias de Venezuela.',
    long_description=README,
    url='http://rub3nc.wordpress.com/',
    author=u'Rubén Colina',
    author_email='ruben.colina@gmail.com',
    classifiers=[
        'Framework :: Django',
        'License :: OSI Approved :: GNU General Public License v2 (GPLv2)',
        'Operating System :: OS Independent',
        'Programming Language :: Python'
    ],
)
